﻿using Map = Microsoft.Maui.Controls.Maps.Map;
using Microsoft.Maui.Maps;
using Microsoft.Maui.Devices.Sensors;
using Microsoft.Maui.Controls.Maps;
namespace MAUImap
{
    public partial class MainPage : ContentPage
    {
        public MainPage()
        {
            InitializeComponent();
            map.IsShowingUser = true;
            map.IsTrafficEnabled = true;
        }

        private void btn_mapType_Clicked(object sender, EventArgs e)
        {
            map.MapType = MapType.Hybrid;
        }

        private async void btn_locate_me_Clicked(object sender, EventArgs e)
        {
            try
            {
                var location = await Geolocation.GetLocationAsync(new GeolocationRequest
                {
                    DesiredAccuracy = GeolocationAccuracy.Medium,
                    Timeout = TimeSpan.FromSeconds(10)
                });

                if (location != null)
                {
                    // Move the map to the user's location
                    map.MoveToRegion(new MapSpan(location, 0.1, 0.1)); // poziom przblizenia 0.1 stopni
                }
                else
                {
                    await DisplayAlert("Error", "Unable to get current location.", "OK");
                }
            }
            catch (PermissionException)
            {
                await DisplayAlert("Error", "Location permission denied.", "OK");
            }
            catch (Exception ex)
            {
                await DisplayAlert("Error", $"An unexpected error occurred: {ex.Message}", "OK");
            }
        }

        private async void map_MapClicked(object sender, Microsoft.Maui.Controls.Maps.MapClickedEventArgs e)
        {
            string label = pin_name.Text;
            if (label == null)
                return;
            var location = e.Location;

            Console.WriteLine($"location: {location.Latitude}, {location.Longitude}");
            IEnumerable<Placemark> placemarks = await Geocoding.Default.GetPlacemarksAsync(location.Latitude, location.Longitude);

            Placemark placemark = placemarks?.FirstOrDefault();
            string adress = "zaznaczone miejsce";
            if(placemark != null)
            {
                adress = placemark.CountryName + " " + placemark.Locality + " " + placemark.SubThoroughfare + " " + placemark.Thoroughfare;
            }

            Pin pin = new Pin()
            {
                Label = label,
                Type = PinType.Generic,
                Address = adress,
                Location = location
            };

            pin.MarkerClicked += async (s, args) =>
            {
                args.HideInfoWindow = true;
                string title = ((Pin)s).Label;
                string adress = ((Pin)s).Address;
                DisplayAlert(title, adress, "Ok");
            };

            pin.InfoWindowClicked += async (s, args) =>
            {
                map.Pins.Remove((Pin)s);
            };

            map.Pins.Add(pin);

            Circle circle = new Circle()
            {
                Center = location,
                Radius = Distance.FromMeters(100),
                FillColor = Color.FromArgb("#CC6CE7"),
                StrokeColor = Color.FromArgb("#E7DDFF")
            };

            map.MapElements.Add(circle);
        }
    }



}
